@@ -1,6 +1,6 @@
 from intelli_gateway.gateway_client import GatewayClient
 
-client = GatewayClient("imngonii@gmail.com", "Nickm@ng13")
+client = GatewayClient("email", "password")
 
 # Authenticate Client
 client.authenticate()
